@@ -541,6 +541,12 @@ our $TREE = {
     lsize  => 1,
     limit  => [0, 0],
     nested => {
+      InitializationMode => {
+        code => 1,
+        func => "uchar",
+        lsize => 1,
+        limit => [ 0, 3 ]
+      },
       ManagementServer  => {
         code   => 2,
         func   => "nested",
@@ -556,6 +562,12 @@ our $TREE = {
           ACSOverride               => {code => 7,  func => "uchar",  lsize => 1, limit => [0, 1]},
         },
       },
+      InitializationModeOverride => {
+        code => 3,
+        func => "uchar",
+        lsize => 1,
+        limit => [ 0, 1 ]
+      },
     },
   },
   VendorSpecific => {code => 43, func => "vendor", lsize => 1, limit => [0, 0],},
